'#### Outlook Samurize Script
'#### Version 1.59
'#### Copyright 2004 - John Newman
'#### Do not distribute without express permission from author
'#### Created by John Newman aka rubjonny, please post feedback to rubjonny@moddin.net

'#### Changelog:
'#### 1.0  25/09/03 - Initial release
'#### 1.1  26/09/03 - Added support for all day calendar entries
'#### 1.11 26/09/03 - Fixed issue with only first instance of a reoccurring calendar item being shown
'#### 1.14 26/09/03 - Removed seconds from returned time values
'#### 1.2  26/09/03 - Added option to show appointment end times and locations
'#### 1.25 02/10/03 - Removed date from item end display if it ends on the same day
'#### 1.3  03/10/03 - Added ability to create "Outlook Today" style config
'#### 1.31 03/10/03 - Fixed small bug with dates for all day events not showing when they should
'#### 1.32 03/10/03 - Fixed tiny bug with events that take place over exactly 24 hours, but aren't all day events
'#### 1.33 06/10/03 - Fixed bug with date showing when it shouldn't under certain circumstances (and some spelling mistakes ;)
'#### 1.34 17/10/03 - Added task and calendar prefix options
'#### 1.40 20/10/03 - Added Experimental offline cache support
'#### 1.45 21/10/03 - Added Inbox support & added more error checking
'#### 1.46 21/10/03 - Fixed a few bugs with Inbox and reoccuring task output
'#### 1.47 21/11/03 - Fixed a non-display bug for tasks with no due date
'#### 1.48 14/01/04 - Added option to suppress year display + more error checking included
'#### 1.49 16/01/04 - Fixed a bug with year removal code, much more robust and should handle years with 4 digits
'#### 1.50 16/01/04 - Added work around for Outlook popup problem, although you will loose the 'From' field support :(
'#### 1.51 05/03/04 - Fixed small bug with unread email check when Outlook language is not English (Thanks Ullrich!)
'#### 1.52 27/04/04 - Fixed small bug where code to strip seconds display would not work if 24h clock was set on the PC
'#### 1.53 27/04/04 - Fixed another bug which prevented tasks with no due date being shown
'#### 1.54 27/04/04 - Added reading of 'Importance' field to Tasks Function, cleaned up function output code
'#### 1.56 27/05/04 - All functions split into fields like the Inbox function
'#### 1.57 27/05/04 - Added quick n' dirty feature to allow sorting mail and task functions by importance
'#### 1.58 28/05/04 - Added ability for Day field to show the date range between 'Firstday' & 'LastDay'
'#### 1.59 08/06/04 - Added option turn off/on display of items with no due date

On Error Resume Next
Set wshFSO   = CreateObject("Scripting.FileSystemObject")

'#### Start of user definable variables
'#### TIP: Setting a separator to "vbCrLf" will move the item to a new line, eg: strSeperator = vbCrLf & " : "

strPrefix     = "*"		'#### Set prefix for items
strSeperator  = " : "		'#### Set separator for calendar/task items
strReoccurSt  = "<"		'#### Set prefix character for reoccurring items
strReoccurEn  = ">"		'#### Set suffix character for reoccurring items
strAllDayDesc = "All day event"	'#### Set description for all day events
strAllDaySt   = ""		'#### Set prefix character for all day events
strAllDayEn   = ""		'#### Set suffix character for  all day events
strSESeperator= " - "		'#### Set separator between appointment start/end dates
strLocationSt = "("		'#### Set prefix character for location
strLocationEn = ")"		'#### Set suffix character for  location
strMailUnread = "*"		'#### Set character for unread email items
strMailUnread = ""		'#### Set character for read email items
strMaxDays    = "30"		'#### Set max number of days in the future to retrieve, helps you have lots of recurring items
strMinDays    = "0"		'#### Set max number of days in the past to retrieve, helps you have lots of recurring items
strCalFile    = "CalFile.txt"	'#### Set Path to offline Calendar cache (relative to Samurize scripts folder)
strTaskFile   = "TaskFile.txt"	'#### Set Path to offline Tasks cache (relative to Samurize scripts folder)
strMailFile   = "MailFile.txt"	'#### Set Path to offline Mail cache (relative to Samurize scripts folder)
strOfflineAge = "4"		'#### Set ammount of time in minutes the Outlook Offline cache files are valid
strFixOutlook = "0"		'#### Enable Outlook popup work around

arrImport     = Array("-","","!") '#### Array containing mail importance symbols (low, normal, high)
arrDay        = Array("Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday","Today") '#### Array containing weekdays

'#### End of user definable variables
strCalFile = wshFSO.GetAbsolutePathName("") & "\scripts\" & strCalFile
strTaskFile = wshFSO.GetAbsolutePathName("") & "\scripts\" & strTaskFile
strMailFile = wshFSO.GetAbsolutePathName("") & "\scripts\" & strMailFile

strOLMode = "0"
If WshFSO.FileExists(strCalFile) And WshFSO.FileExists(strTaskFile) And WshFSO.FileExists(strMailFile) Then
  strOLMode = "1"
  If now - WshFSO.GetFile(strCalFile).DateLastModified > strOfflineAge/1440 Or now - WshFSO.GetFile(strTaskFile).DateLastModified > strOfflineAge/1441 Or now - WshFSO.GetFile(strMailFile).DateLastModified > strOfflineAge/1442 Then
    strOLMode = "0"
  End If
Else
  strOLMode = "0"
End If

If strOLMode = "0" Then
Set objApp = GetObject(, "Outlook.Application")		'#### Find existing instance of Outlook
If Err=0 Then
  Set objOutlook = objApp.GetNameSpace("MAPI")		'#### Get MAPI namespace

  Set objCalItems  = objOutlook.GetDefaultFolder(9).Items	'#### Get Calendar folder items
  Set objTaskItems = objOutlook.GetDefaultFolder(13).Items	'#### Get Task folder items
  Set objMailItems = objOutlook.GetDefaultFolder(6).Items	'#### Get Inbox folder items

  objTaskItems.IncludeRecurrences = True		'#### Include  reoccurring task items
  objCalItems.IncludeRecurrences = True			'#### Include  reoccurring calendar items

  dtRestMin = cdate(Date-strMinDays-1)			'#### Set min & max restriction dates
  dtRestMax = cdate(Date+strMaxDays)
  objCalItems.Sort "[Start]", False
  objMailItems.Sort "[ReceivedTime]", True

  strRestrict = "[Start] >= '" & dtRestMin & "' and [Start] <= '" & dtRestMax & "'"
  Set objCalItems = objCalItems.Restrict(strRestrict)	'#### Restrict returned items (helps when you have lots of recurring items)

  objCalItems.Sort "[Start]", False
  objTaskItems.Sort "[DueDate]", False			'#### Sort items
  objMailItems.Sort "[ReceivedTime]", True

  Set objTextStream1 = wshFSO.CreateTextFile(strCalFile, True)
  Set objTextStream2 = wshFSO.CreateTextFile(strTaskFile, True)
  Set objTextStream3 = wshFSO.CreateTextFile(strMailFile, True)
  For each item in objCalItems
    If item.IsRecurring = True then
       strCalRecuring = "True"
    Else
       strCalRecuring = "False"
    End If
    objTextStream1.Writeline item.Start & "%1%" & item.End & "%2%" & item & "%3%" & item.Location & "%4%" & strCalRecuring & "%5%"
  Next
  For each item in objTaskItems
    If Item.Complete = True then 
      strTaskCompleted = "True"
    Else
       strTaskCompleted = "False"
    End If
    If item.IsRecurring = True then
       strTaskRecuring = "True"
    Else
       strTaskRecuring = "False"
    End If
    objTextStream2.Writeline Item.DueDate & "%1%" & item.DateCompleted & "%2%" & Item.Subject & "%3%" & strTaskCompleted & "%4%" & strTaskRecuring & "%5%" & Item.Importance & "%6%"
  Next
  strMUnread = "0"
  strMTotal  = "0"
  For each item in objMailItems
    If Item.ReceivedTime <> "" Then
      If strFixOutlook <> "1" Then
        strItemSenderName = Item.SenderName
      Else
        strItemSenderName = "[null]"
      End If
      objTextStream3.Writeline Item.UnRead & "%1%" & Item.ReceivedTime & "%2%" & Item.Subject & "%3%" & strItemSenderName & "%4%" & Item.Importance & "%5%"
      If Item.Unread = True Then strMUnread = strMUnread+1
      strMTotal = strMTotal+1
    End If
  Next
  objtextstream3.Writeline strMTotal & "%Total%" & strMUnread & "%Unread%"
  objTextStream1.close
  objTextStream2.close
  objTextStream3.close
End If
End If

Set dicCalendar = CreateObject("Scripting.Dictionary")	'#### Create offline calendar array
strIndex = 0
If WshFSO.FileExists(strCalFile) Then
  Set objTextStream1 = WshFSO.OpenTextFile(strCalFile)	'#### Open offline calendar file
  Do while Not objTextStream1.AtEndOfStream		'#### Keep going till the end of the file
    strInput = objTextStream1.ReadLine			'#### Read a line from the file
    If len(trim(strInput)) > 0 And left(strInput,1) <> ";" Then	'#### Ignore blank lines and ";" character
      strIndex = strIndex + 1
      dicCalendar.Add strIndex, strInput		'#### Write the calendar item to the array
    End If
  Loop
End If

Set dicTasks = CreateObject("Scripting.Dictionary")	'#### Create offline tasks array
strIndex = 0
If WshFSO.FileExists(strTaskFile) Then
  Set objTextStream1 = WshFSO.OpenTextFile(strTaskFile)	'#### Open offline tasks file
  Do while Not objTextStream1.AtEndOfStream		'#### Keep going till the end of the file
    strInput = objTextStream1.ReadLine			'#### Read a line from the file
    If len(trim(strInput)) > 0 And left(strInput,1) <> ";" Then	'#### Ignore blank lines and ";" character
      strIndex = strIndex + 1
      dicTasks.Add strIndex, strInput			'#### Write the task item to the array
    End If
  Loop
End If

Set dicMail = CreateObject("Scripting.Dictionary")	'#### Create offline email array
strIndex = 0
If WshFSO.FileExists(strCalFile) Then
  Set objTextStream1 = WshFSO.OpenTextFile(strMailFile)	'#### Open offline email file
  Do while Not objTextStream1.AtEndOfStream		'#### Keep going till the end of the file
    strInput = objTextStream1.ReadLine			'#### Read a line from the file
    If len(trim(strInput)) > 0 And left(strInput,1) <> ";" Then	'#### Ignore blank lines and ";" character
      strIndex = strIndex + 1
      dicMail.Add strIndex, strInput			'#### Write the email item to the array
    End If
  Loop
End If
objTextStream1.close
objTextStream2.close
objTextStream3.close

Function calendar(Field,FirstDay,LastDay,ShowEnd,ShowYear)
If Field    = "" Then Field = "Day"
If Firstday = "" Then Firstday = "0"
If LastDay  = "" Then LastDay = FirstDay
If ShowEnd  <> "1" Then ShowEnd = "0"
If ShowYear <> "1" Then ShowYear = "0"

dtDateMin = Date + FirstDay & " 12:00:00 am"		'#### Set min & max dates
dtDateMax = Date + LastDay  & " 11:59:59 pm"

If FirstDay = "0" Then
  strItemDay = arrDay(7)
ElseIf FirstDay <> LastDay Then
  If ShowYear = "0" Then
    If instr(Date + FirstDay,"/") <> 0 Then
      strItemDay = left(Date + FirstDay,InStrRev(Date + FirstDay,"/")-1) & strSESeperator & left(Date + LastDay,InStrRev(Date + LastDay,"/")-1)
    End If
  Else
    strItemDay = Date + FirstDay & strSESeperator & Date + LastDay
  End If
Else
  strItemDay = arrDay(Weekday(Date + FirstDay)-1)
End If

For i=1 to dicCalendar.Count
  strItemStart   = left(dicCalendar.item(i),instr(dicCalendar.item(i),"%1%")-1)
  strItemEnd     = mid(dicCalendar.item(i),instr(dicCalendar.item(i),"%1%")+3,instr(dicCalendar.item(i),"%2%") - instr(dicCalendar.item(i),"%1%")-3)
  strItemSubject = mid(dicCalendar.item(i),instr(dicCalendar.item(i),"%2%")+3,instr(dicCalendar.item(i),"%3%") - instr(dicCalendar.item(i),"%2%")-3)
  strItemLoc     = mid(dicCalendar.item(i),instr(dicCalendar.item(i),"%3%")+3,instr(dicCalendar.item(i),"%4%") - instr(dicCalendar.item(i),"%3%")-3)
  strItemRec     = mid(dicCalendar.item(i),instr(dicCalendar.item(i),"%4%")+3,instr(dicCalendar.item(i),"%5%") - instr(dicCalendar.item(i),"%4%")-3)
  strItemRecSt   = strReoccurSt
  strItemRecEn   = strReoccurEn

  If cdate(strItemStart) = date + FirstDay Or cdate(strItemStart) >= cdate(dtDateMin) And cdate(strItemStart) <= cdate(dtDateMax) Then	'#### Check item is in date range
    If right(strItemStart,3) = ":00" Then
      strItemStart = ltrim(left(strItemStart,len(strItemStart)-3))
      strItemEnd = ltrim(left(strItemEnd,len(strItemEnd)-3))
    Else
      strItemStart = ltrim(Replace(strItemStart,":00 "," "))
      strItemEnd = ltrim(Replace(strItemEnd,":00 "," "))
    End If

    If ShowYear = "0" Then
      If instr(strItemEnd,"/") <> 0 Then
        If instr(strItemEnd,":") <> 0 Then
          strItemEnd = left(strItemEnd,InStrRev(strItemEnd,"/")-1) & " " & ltrim(right(strItemEnd,len(strItemEnd)-instr(strItemEnd,":")+3))
        Else
          strItemEnd = left(strItemEnd,InStrRev(strItemEnd,"/")-1)
        End If
      End If
      If instr(strItemStart,"/") <> 0 Then
        If instr(strItemStart,":") <> 0 Then
          strItemDate = left(strItemStart,InStrRev(strItemStart,"/")-1) & " " & ltrim(right(strItemStart,len(strItemStart)-instr(strItemStart,":")+3))
        Else
          strItemDate = left(strItemStart,InStrRev(strItemStart,"/")-1)
        End If
      End If
    End If

    If FirstDay = LastDay Then
      strItemDate = ltrim(Replace(strItemStart,Date + FirstDay ,""))
    End If

    If ShowEnd = "1" Then
      If cdate(strItemEnd) - cdate(strItemStart) >= 1 Then
        strItemDate = strItemDate & strSESeperator & strItemEnd
      Else
        strItemDate = strItemDate & strSESeperator & ltrim(Right(strItemEnd,Len(strItemEnd)-(InStr(strItemEnd,":")-3)))	'#### If option is enabled show the end time for the appointment
      End If
    End If

    If instr(strItemStart,":")="0" Then
      If FirstDay = LastDay Or strItemStart = "" Then
        strItemDate = strAllDayDesc
      Else
        strItemDate = strAllDayDesc & strSeperator & strItemStart
      End If
    End If

    If strItemRec = "False" Then
      strItemRecSt = ""
      strItemRecEn = ""
    End If

    If strItemLoc <> "" Then
       strItemLocation = strLocationSt & strItemLoc & strLocationEn
    End If

    If lcase(Field) = "prefix"     Then calendar = calendar & strPrefix & vbCrLf
    If lcase(Field) = "reocurstart" Then calendar = calendar & strItemRecSt & vbCrLf
    If lcase(Field) = "reocurend"   Then calendar = calendar & strItemRecEn & vbCrLf
    If lcase(Field) = "date"       Then calendar = calendar & strItemDate & vbCrLf
    If lcase(Field) = "subject"    Then calendar = calendar & strItemSubject & vbCrLf
    If lcase(Field) = "location"   Then calendar = calendar & strItemLocation & vbCrLf
    If lcase(Field) = "seperator"  Then calendar = calendar & strSeperator & vbCrLf
  End If
Next
If lcase(Field) = "day"         Then calendar = strItemDay
End Function

Function tasks(Field,FirstDay,LastDay,ShowYear,SortByImportance,ShowNoDueDate)
If Field    = "" Then Field = "Day"
If Firstday = "" Then Firstday = "0"
If LastDay  = "" Then LastDay = FirstDay
If ShowYear <> "1" Then ShowYear = "0"
If SortByImportance <> "1" Then SortByImportance = "0"
If ShowNoDueDate <> "1" Then ShowNoDueDate = "0"

dtDateMin = Date + FirstDay & " 12:00:00 am"	'#### Set min & max dates
dtDateMax = Date + LastDay  & " 11:59:59 pm"

If FirstDay = "0" Then
  strItemDay = arrDay(7)
ElseIf FirstDay <> LastDay Then
  If ShowYear = "0" Then
    If instr(Date + FirstDay,"/") <> 0 Then
      strItemDay = left(Date + FirstDay,InStrRev(Date + FirstDay,"/")-1) & strSESeperator & left(Date + LastDay,InStrRev(Date + LastDay,"/")-1)
    End If
  Else
    strItemDay = Date + FirstDay & strSESeperator & Date + LastDay
  End If
Else
  strItemDay = arrDay(Weekday(Date + FirstDay)-1)
End If

For i=1 to dicTasks.Count
  strItemDueDate  = left(dicTasks.item(i),instr(dicTasks.item(i),"%1%")-1)
  strItemSubject  = mid(dicTasks.item(i),instr(dicTasks.item(i),"%2%")+3,instr(dicTasks.item(i),"%3%") - instr(dicTasks.item(i),"%2%")-3)
  strItemComplete = mid(dicTasks.item(i),instr(dicTasks.item(i),"%3%")+3,instr(dicTasks.item(i),"%4%") - instr(dicTasks.item(i),"%3%")-3)
  strItemRec      = mid(dicTasks.item(i),instr(dicTasks.item(i),"%4%")+3,instr(dicTasks.item(i),"%5%") - instr(dicTasks.item(i),"%4%")-3)
  strItemImport   = mid(dicTasks.item(i),instr(dicTasks.item(i),"%5%")+3,instr(dicTasks.item(i),"%6%") - instr(dicTasks.item(i),"%5%")-3)
  strItemRecSt    = strReoccurSt
  strItemRecEn    = strReoccurEn

  If strItemComplete = "False" Then									'#### Make sure item is not completed
    If cdate(strItemDueDate) >= cdate(dtDateMin) And cdate(strItemDueDate) <= cdate(dtDateMax) Or cdate(strItemDueDate) = cdate("01/01/4501") And ShowNoDueDate = "1" Then	'#### Check item is in date range
    
    If cdate(strItemDueDate) = cdate("01/01/4501") Then
      strItemDueDate = "None"	'#### Tasks without a user set date have "01/01/4501" in their duedate field
    End If

    If ShowYear = "0" and instr(strItemDueDate,"/") <> 0 Then
      strItemDueDate = left(strItemDueDate,InStrRev(strItemDueDate,"/")-1)
    End If

    If strItemRec = "False" Then
      strItemRecSt = ""
      strItemRecEn = ""
    End If

If SortByImportance = "1" Or SortByImportance = "2" Then
    If strItemImport = "0" Then
    If lcase(Field) = "prefix"     Then strLTasks = strLTasks & strPrefix & vbCrLf
    If lcase(Field) = "reocurstart" Then strLTasks = strLTasks & strItemRecSt & vbCrLf
    If lcase(Field) = "reocurend"   Then strLTasks = strLTasks & strItemRecEn & vbCrLf
    If lcase(Field) = "date"       Then strLTasks = strLTasks & strItemDueDate & vbCrLf
    If lcase(Field) = "subject"    Then strLTasks = strLTasks & strItemSubject & vbCrLf
    If lcase(Field) = "importance" Then strLTasks = strLTasks & arrImport(strItemImport) & vbCrLf
    If lcase(Field) = "seperator"  Then strLTasks = strLTasks & strSeperator & vbCrLf
    
    ElseIf strItemImport = "1" Then
    If lcase(Field) = "prefix"     Then strMTasks = strMTasks & strPrefix & vbCrLf
    If lcase(Field) = "reocurstart" Then strMTasks = strMTasks & strItemRecSt & vbCrLf
    If lcase(Field) = "reocurend"   Then strMTasks = strMTasks & strItemRecEn & vbCrLf
    If lcase(Field) = "date"       Then strMTasks = strMTasks & strItemDueDate & vbCrLf
    If lcase(Field) = "subject"    Then strMTasks = strMTasks & strItemSubject & vbCrLf
    If lcase(Field) = "importance" Then strMTasks = strMTasks & arrImport(strItemImport) & vbCrLf
    If lcase(Field) = "seperator"  Then strMTasks = strMTasks & strSeperator & vbCrLf

    Else
    If lcase(Field) = "prefix"     Then strHTasks = strHTasks & strPrefix & vbCrLf
    If lcase(Field) = "reocurstart" Then strHTasks = strHTasks & strItemRecSt & vbCrLf
    If lcase(Field) = "reocurend"   Then strHTasks = strHTasks & strItemRecEn & vbCrLf
    If lcase(Field) = "date"       Then strHTasks = strHTasks & strItemDueDate & vbCrLf
    If lcase(Field) = "subject"    Then strHTasks = strHTasks & strItemSubject & vbCrLf
    If lcase(Field) = "importance" Then strHTasks = strHTasks & arrImport(strItemImport) & vbCrLf
    If lcase(Field) = "seperator"  Then strHTasks = strHTasks & strSeperator & vbCrLf
    End If
Else
    If lcase(Field) = "prefix"     Then tasks = tasks & strPrefix & vbCrLf
    If lcase(Field) = "reocurstart" Then tasks = tasks & strItemRecSt & vbCrLf
    If lcase(Field) = "reocurend"   Then tasks = tasks & strItemRecEn & vbCrLf
    If lcase(Field) = "date"       Then tasks = tasks & strItemDueDate & vbCrLf
    If lcase(Field) = "subject"    Then tasks = tasks & strItemSubject & vbCrLf
    If lcase(Field) = "importance" Then tasks = tasks & arrImport(strItemImport) & vbCrLf
    If lcase(Field) = "seperator"  Then tasks = tasks & strSeperator & vbCrLf
End If
    End If
  End If
Next
If lcase(Field) = "day" Then 
  tasks = strItemDay
ElseIf SortByImportance = "1" Then
  tasks = strHTasks & strMTasks & strLTasks
ElseIf SortByImportance = "2" Then
  tasks = strLTasks & strMTasks & strHTasks
End If

End Function

Function completed_tasks(Field,TasksBehind,TasksAhead,ShowYear,SortByImportance)
If Field       = "" Then Field = "prefix"
If TasksBehind = "" Then TasksBehind = strMaxDays
If TasksAhead  = "" Then TasksAhead = "0"
If ShowYear    <> "1" Then ShowYear = "0"
If SortByImportance <> "1" Then SortByImportance = "0"

dtDateMin = Date - TasksBehind & " 12:00:00 am"	'#### Set min & max dates
dtDateMax = Date + TasksAhead  & " 11:59:59 pm"

For i=1 to dicTasks.Count
  strItemDueDate  = left(dicTasks.item(i),instr(dicTasks.item(i),"%1%")-1)
  strItemDateComp = mid(dicTasks.item(i),instr(dicTasks.item(i),"%1%")+3,instr(dicTasks.item(i),"%2%") - instr(dicTasks.item(i),"%1%")-3)
  strItemSubject  = mid(dicTasks.item(i),instr(dicTasks.item(i),"%2%")+3,instr(dicTasks.item(i),"%3%") - instr(dicTasks.item(i),"%2%")-3)
  strItemComplete = mid(dicTasks.item(i),instr(dicTasks.item(i),"%3%")+3,instr(dicTasks.item(i),"%4%") - instr(dicTasks.item(i),"%3%")-3)
  strItemRec      = mid(dicTasks.item(i),instr(dicTasks.item(i),"%4%")+3,instr(dicTasks.item(i),"%5%") - instr(dicTasks.item(i),"%4%")-3)
  strItemImport   = mid(dicTasks.item(i),instr(dicTasks.item(i),"%5%")+3,instr(dicTasks.item(i),"%6%") - instr(dicTasks.item(i),"%5%")-3)
  strItemRecSt    = strReoccurSt
  strItemRecEn    = strReoccurEn

  If strItemComplete = "True" And cdate(strItemDateComp) >= cdate(dtDateMin) And cdate(strItemDateComp) <= cdate(dtDateMax) Then	'#### Check item is in date range
    If ShowYear = "0" and instr(strItemDateComp,"/") <> 0 Then
      strItemDateComp = left(strItemDateComp,InStrRev(strItemDateComp,"/")-1)
    End If
    If strItemRec = "False" Then
      strItemRecSt = ""
      strItemRecEn = ""
    End If

If SortByImportance = "1" Or SortByImportance = "2" Then
    If strItemImport = "0" Then
    If lcase(Field) = "prefix"     Then strLTasks = strLTasks & strPrefix & vbCrLf
    If lcase(Field) = "reocurstart" Then strLTasks = strLTasks & strItemRecSt & vbCrLf
    If lcase(Field) = "reocurend"   Then strLTasks = strLTasks & strItemRecEn & vbCrLf
    If lcase(Field) = "date"       Then strLTasks = strLTasks & strItemDateComp & vbCrLf
    If lcase(Field) = "subject"    Then strLTasks = strLTasks & strItemSubject & vbCrLf
    If lcase(Field) = "importance" Then strLTasks = strLTasks & arrImport(strItemImport) & vbCrLf
    If lcase(Field) = "seperator"  Then strLTasks = strLTasks & strSeperator & vbCrLf
    
    ElseIf strItemImport = "1" Then
    If lcase(Field) = "prefix"     Then strMTasks = strMTasks & strPrefix & vbCrLf
    If lcase(Field) = "reocurstart" Then strMTasks = strMTasks & strItemRecSt & vbCrLf
    If lcase(Field) = "reocurend"   Then strMTasks = strMTasks & strItemRecEn & vbCrLf
    If lcase(Field) = "date"       Then strMTasks = strMTasks & strItemDateComp & vbCrLf
    If lcase(Field) = "subject"    Then strMTasks = strMTasks & strItemSubject & vbCrLf
    If lcase(Field) = "importance" Then strMTasks = strMTasks & arrImport(strItemImport) & vbCrLf
    If lcase(Field) = "seperator"  Then strMTasks = strMTasks & strSeperator & vbCrLf

    Else
    If lcase(Field) = "prefix"     Then strHTasks = strHTasks & strPrefix & vbCrLf
    If lcase(Field) = "reocurstart" Then strHTasks = strHTasks & strItemRecSt & vbCrLf
    If lcase(Field) = "reocurend"   Then strHTasks = strHTasks & strItemRecEn & vbCrLf
    If lcase(Field) = "date"       Then strHTasks = strHTasks & strItemDateComp & vbCrLf
    If lcase(Field) = "subject"    Then strHTasks = strHTasks & strItemSubject & vbCrLf
    If lcase(Field) = "importance" Then strHTasks = strHTasks & arrImport(strItemImport) & vbCrLf
    If lcase(Field) = "seperator"  Then strHTasks = strHTasks & strSeperator & vbCrLf
    End If
Else
    If lcase(Field) = "prefix"     Then completed_tasks = completed_tasks & strPrefix & vbCrLf
    If lcase(Field) = "reocurstart" Then completed_tasks = completed_tasks & strItemRecSt & vbCrLf
    If lcase(Field) = "reocurend"   Then completed_tasks = completed_tasks & strItemRecEn & vbCrLf
    If lcase(Field) = "date"       Then completed_tasks = completed_tasks & strItemDateComp & vbCrLf
    If lcase(Field) = "subject"    Then completed_tasks = completed_tasks & strItemSubject & vbCrLf
    If lcase(Field) = "importance" Then completed_tasks = completed_tasks & arrImport(strItemImport) & vbCrLf
    If lcase(Field) = "seperator"  Then completed_tasks = completed_tasks & strSeperator & vbCrLf
End If
  End If
Next
If SortByImportance = "1" Then
  completed_tasks = strHTasks & strMTasks & strLTasks
ElseIf SortByImportance = "2" Then
  completed_tasks = strLTasks & strMTasks & strHTasks
End If
End Function

Function inbox(Field,MaxItems,LastDay,ShowYear,SortByImportance)
If Field    = "" Then Field = "Total"
If LastDay  = "" Then LastDay = strMaxDays
If MaxItems = "" Then MaxItems = "30"
If ShowYear <> "1" Then ShowYear = "0"
If SortByImportance <> "1" Then SortByImportance = "0"

If lcase(Field) = "total" Or lcase(Field) = "read" Or lcase(Field) = "unread" Then
  If instr(dicMail.item(dicMail.Count),"%Total%") > 0 Then
    strMTotal  = left(dicMail.item(dicMail.Count),instr(dicMail.item(dicMail.Count),"%Total%")-1)
    strMUnread = mid(dicMail.item(dicMail.Count),instr(dicMail.item(dicMail.Count),"%Total%")+7,instr(dicMail.item(dicMail.Count),"%Unread%") - instr(dicMail.item(dicMail.Count),"%Total%")-7)

    If lcase(Field) = "total" Then Inbox = strMTotal
    If lcase(Field) = "unread" Then Inbox = strMUnread
    If lcase(Field) = "read" Then Inbox = strMTotal - strMUnread
  Else
    Inbox = "0"
  End If
Else
dtDateMin = Date - LastDay & " 12:00:00 am"	'#### Set min & max dates

If LastDay = "" Then LastDay = strMaxDays
If MaxItems = "" Or MaxItems = "0" Then MaxItems = dicMail.Count-1
If cint(MaxItems) >= dicMail.Count-1 Then MaxItems = dicMail.Count-1

For i=1 to MaxItems
  strItemUnread   = left(dicMail.item(i),instr(dicMail.item(i),"%1%")-1)
  strItemRecieved = mid(dicMail.item(i),instr(dicMail.item(i),"%1%")+3,instr(dicMail.item(i),"%2%") - instr(dicMail.item(i),"%1%")-3)
  strItemSubject  = mid(dicMail.item(i),instr(dicMail.item(i),"%2%")+3,instr(dicMail.item(i),"%3%") - instr(dicMail.item(i),"%2%")-3)
  strItemSender   = mid(dicMail.item(i),instr(dicMail.item(i),"%3%")+3,instr(dicMail.item(i),"%4%") - instr(dicMail.item(i),"%3%")-3)
  strItemImport   = mid(dicMail.item(i),instr(dicMail.item(i),"%4%")+3,instr(dicMail.item(i),"%5%") - instr(dicMail.item(i),"%4%")-3)

  If cdate(strItemRecieved) >= cdate(dtDateMin) Then	'#### Check item is in date range
    If ShowYear = "0" and instr(strItemRecieved,"/") <> 0 Then
      If instr(strItemRecieved,":") <> 0 Then
        strItemRecieved = left(strItemRecieved,InStrRev(strItemRecieved,"/")-1) & " " & ltrim(right(strItemRecieved,len(strItemRecieved)-instr(strItemRecieved,":")+3))
      Else
        strItemRecieved = left(strItemRecieved,InStrRev(strItemRecieved,"/")-1)
      End If
    End If

    If strItemUnread = "True" Then
      strItemStatus = strMailUnread
    Else
      strItemStatus = strMailRead
    End If

If SortByImportance = "1" Or SortByImportance = "2" Then
    If strItemImport = "0" Then
    If lcase(Field) = "prefix"     Then strLInbox = strLInbox & strPrefix & vbCrLf
    If lcase(Field) = "from"       Then strLInbox = strLInbox & strItemSender & vbCrLf
    If lcase(Field) = "subject"    Then strLInbox = strLInbox & strItemSubject & vbCrLf
    If lcase(Field) = "date"       Then strLInbox = strLInbox & strItemRecieved & vbCrLf
    If lcase(Field) = "importance" Then strLInbox = strLInbox & arrImport(strItemImport) & vbCrLf
    If lcase(Field) = "seperator"  Then strLInbox = strLInbox & strSeperator & vbCrLf
    If lcase(Field) = "status"     Then strLInbox = strLInbox & strItemStatus & vbCrLf
   
    ElseIf strItemImport = "1" Then
    If lcase(Field) = "prefix"     Then strMInbox = strMInbox & strPrefix & vbCrLf
    If lcase(Field) = "from"       Then strMInbox = strMInbox & strItemSender & vbCrLf
    If lcase(Field) = "subject"    Then strMInbox = strMInbox & strItemSubject & vbCrLf
    If lcase(Field) = "date"       Then strMInbox = strMInbox & strItemRecieved & vbCrLf
    If lcase(Field) = "importance" Then strMInbox = strMInbox & arrImport(strItemImport) & vbCrLf
    If lcase(Field) = "seperator"  Then strMInbox = strMInbox & strSeperator & vbCrLf
    If lcase(Field) = "status"     Then strMInbox = strMInbox & strItemStatus & vbCrLf

    Else
    If lcase(Field) = "prefix"     Then strHInbox = strHInbox & strPrefix & vbCrLf
    If lcase(Field) = "from"       Then strHInbox = strHInbox & strItemSender & vbCrLf
    If lcase(Field) = "subject"    Then strHInbox = strHInbox & strItemSubject & vbCrLf
    If lcase(Field) = "date"       Then strHInbox = strHInbox & strItemRecieved & vbCrLf
    If lcase(Field) = "importance" Then strHInbox = strHInbox & arrImport(strItemImport) & vbCrLf
    If lcase(Field) = "seperator"  Then strHInbox = strHInbox & strSeperator & vbCrLf
    If lcase(Field) = "status"     Then strHInbox = strHInbox & strItemStatus & vbCrLf
    End If
Else
    If lcase(Field) = "prefix"     Then Inbox = Inbox & strPrefix & vbCrLf
    If lcase(Field) = "from"       Then Inbox = Inbox & strItemSender & vbCrLf
    If lcase(Field) = "subject"    Then Inbox = Inbox & strItemSubject & vbCrLf
    If lcase(Field) = "date"       Then Inbox = Inbox & strItemRecieved & vbCrLf
    If lcase(Field) = "importance" Then Inbox = Inbox & arrImport(strItemImport) & vbCrLf
    If lcase(Field) = "seperator"  Then Inbox = Inbox & strSeperator & vbCrLf
    If lcase(Field) = "status"     Then Inbox = Inbox & strItemStatus & vbCrLf
End If
  End If
Next
If SortByImportance = "1" Then
  Inbox = strHInbox & strMInbox & strLInbox
ElseIf SortByImportance = "2" Then
  Inbox = strLInbox & strMInbox & strHInbox
End If
End If
End Function